pub struct ControlInfo {
pub control_type: ControlType,
pub format: String,
pub properties: HashMap<String, String>,
}Expand description
https://www.rdfhdt.org/hdt-binary-format/: “preamble that describes a chunk of information”.
Fields
control_type: ControlTypeType of control information.
format: String“URI identifier of the implementation of the following section.”
properties: HashMap<String, String>Key-value entries, ASCII only.
Implementations
Sourceimpl ControlInfo
impl ControlInfo
Sourcepub fn global() -> ControlInfo
pub fn global() -> ControlInfo
Create global control information for the start of the HDT file
Sourcepub fn header(length: usize) -> ControlInfo
pub fn header(length: usize) -> ControlInfo
Create control information for the header
Sourcepub fn four_sect_dict() -> ControlInfo
pub fn four_sect_dict() -> ControlInfo
Create control information for the four section dictionary
Sourcepub fn bitmap_triples(order: u32, num_triples: u32) -> ControlInfo
pub fn bitmap_triples(order: u32, num_triples: u32) -> ControlInfo
Create control information for BitmapTriples